@@ -1,24 +1,14 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
+
 #include "filteractionwithaddresstest.h"
 #include "../filteractions/filteractionwithaddress.h"
-#include <qtest.h>
+#include <Akonadi/EmailAddressRequester>
+#include <QTest>
 #include <QWidget>
-#include <Akonadi/Contact/EmailAddressRequester>
 
 class TestFilterActionWithAddress : public MailCommon::FilterActionWithAddress
 {
@@ -33,7 +23,7 @@ public:
         return GoOn;
     }
 
-    MailCommon::SearchRule::RequiredPart requiredPart() const override
+    Q_REQUIRED_RESULT MailCommon::SearchRule::RequiredPart requiredPart() const override
     {
         return MailCommon::SearchRule::CompleteMessage;
     }
@@ -44,16 +34,14 @@ FilterActionWithAddressTest::FilterActionWithAddressTest(QObject *parent)
 {
 }
 
-FilterActionWithAddressTest::~FilterActionWithAddressTest()
-{
-}
+FilterActionWithAddressTest::~FilterActionWithAddressTest() = default;
 
 void FilterActionWithAddressTest::shouldHaveDefaultValue()
 {
     TestFilterActionWithAddress filter;
     QWidget *w = filter.createParamWidget(nullptr);
     QCOMPARE(w->objectName(), QStringLiteral("emailaddressrequester"));
-    Akonadi::EmailAddressRequester *requester = dynamic_cast<Akonadi::EmailAddressRequester *>(w);
+    auto *requester = dynamic_cast<Akonadi::EmailAddressRequester *>(w);
     QVERIFY(requester);
     QVERIFY(filter.isEmpty());
 }
@@ -62,7 +50,7 @@ void FilterActionWithAddressTest::shouldAssignValue()
 {
     TestFilterActionWithAddress filter;
     QWidget *w = filter.createParamWidget(nullptr);
-    Akonadi::EmailAddressRequester *requester = dynamic_cast<Akonadi::EmailAddressRequester *>(w);
+    auto *requester = dynamic_cast<Akonadi::EmailAddressRequester *>(w);
     filter.argsFromString(QStringLiteral("foo"));
     filter.setParamWidgetValue(w);
     QVERIFY(!filter.isEmpty());
